__version__ = '0.1.16'
from luvex.node import Node
from luvex.decisiontree import DecisionTree
from luvex.randomforest import RandomForest
from luvex.knn import KNN
from luvex.logisticregression import Logisticregression
from luvex.Linearregression import Linearregression
from luvex.multilinear import MultipleLinear
